@@ -5,20 +5,20 @@ use strict;
 use Graphics::Framebuffer;
 use List::Util qw(min max);
 
-$| = 1;
 system('clear');
+$| = 1;
 
 my $mali = 0;
 my $file = 0;
-my $arg = join('',@ARGV);
+my $arg  = join('', @ARGV);
 
-$mali = 1 if ($arg =~ /mali/i); # Mali GPU correction mode
-$file = 1 if ($arg =~ /file/i); # File Handle drawing mode
+$mali = 1 if ($arg =~ /mali/i);    # Mali GPU correction mode
+$file = 1 if ($arg =~ /file/i);    # File Handle drawing mode
 
-my $F = Graphics::Framebuffer->new('MALI' => $mali, 'FB_DEVICE' => '/dev/fb0','FILE_MODE' => $file,'SHOW_ERRORS' => 1,'LINE_PADDING'=> 0);
+my $F = Graphics::Framebuffer->new('MALI' => $mali, 'FB_DEVICE' => '/dev/fb0', 'FILE_MODE' => $file, 'SHOW_ERRORS' => 1, 'LINE_PADDING' => 0);
 
-$SIG{'QUIT'} = sub { $F->cls('ON'); exit(0); };
-$SIG{'INT'}  = sub { $F->cls('ON'); exit(0); };
+$SIG{'QUIT'} = sub {$F->cls('ON'); exit(0);};
+$SIG{'INT'}  = sub {$F->cls('ON'); exit(0);};
 
 my $screen_width  = $F->{'XRES'};
 my $screen_height = $F->{'YRES'};
@@ -37,12 +37,12 @@ my $s = time + $factor;
 while (time < $s) {
     my $x = int(rand($screen_width));
     my $y = int(rand($screen_height));
-    $F->set_color({'alpha' => 255,'red' => rand(256), 'green' => rand(256), 'blue' => rand(256)});
+    $F->set_color({'alpha' => 255, 'red' => rand(256), 'green' => rand(256), 'blue' => rand(256)});
     $F->plot({'x' => $x, 'y' => $y});
-}
+} ## end while (time < $s)
 
 print_it($F, 'Line Test');
-for (my $l = $F->{'Y_CLIP'} ; $l < $YY ; $l += 4) {
+for (my $l = $F->{'Y_CLIP'} ; $l < $YY ; $l += 8) {
     $F->set_color({'red' => rand(256), 'green' => rand(256), 'blue' => rand(256)});
     $F->line({'x' => 0, 'y' => $l, 'xx' => $XX, 'yy' => $l});
 
@@ -51,12 +51,12 @@ for (my $l = $F->{'Y_CLIP'} ; $l < $YY ; $l += 4) {
 
     $F->set_color({'red' => rand(256), 'green' => rand(256), 'blue' => rand(256)});
     $F->line({'x' => $XX, 'y' => $l, 'xx' => $XX - $l, 'yy' => $F->{'Y_CLIP'}});
-    
+
     $F->set_color({'red' => rand(256), 'green' => rand(256), 'blue' => rand(256)});
     $F->line({'x' => $XX, 'y' => $YY - $l, 'xx' => $XX - $l, 'yy' => $F->{'Y_CLIP'}});
 
-} ## end for (my $l = 40 ; $l < ...)
-for (my $l = 0 ; $l < $XX ; $l += 4) {
+} ## end for (my $l = $F->{'Y_CLIP'...})
+for (my $l = 0 ; $l < $XX ; $l += 8) {
     $F->set_color({'red' => rand(256), 'green' => rand(256), 'blue' => rand(256)});
     $F->line({'x' => $l, 'y' => $F->{'Y_CLIP'}, 'xx' => $l, 'yy' => $YY});
 }
@@ -82,25 +82,25 @@ while (time < $s) {
     $F->box(
         {
             'x'        => rand($XX),
-              'y'        => rand($YY),
-              'xx'       => rand($XX),
-              'yy'       => rand($YY),
-              'filled'   => 1,
-              'gradient' => {
-                  'start' => {
-                      'red'   => rand(256),
-                      'green' => rand(256),
-                      'blue'  => rand(256)
-                  },
-                  'end' => {
-                      'red'   => rand(256),
-                      'green' => rand(256),
-                      'blue'  => rand(256)
-                  }
-              }
+            'y'        => rand($YY),
+            'xx'       => rand($XX),
+            'yy'       => rand($YY),
+            'filled'   => 1,
+            'gradient' => {
+                'start' => {
+                    'red'   => rand(256),
+                    'green' => rand(256),
+                    'blue'  => rand(256)
+                },
+                'end' => {
+                    'red'   => rand(256),
+                    'green' => rand(256),
+                    'blue'  => rand(256)
+                }
+            }
         }
     );
-} ## end foreach my $p (1 .. (20 * $factor...))
+} ## end while (time < $s)
 
 print_it($F, 'Rounded Box Test');
 $s = time + $factor;
@@ -121,28 +121,28 @@ $s = time + $factor;
 while (time < $s) {
     $F->set_color({'red' => rand(256), 'green' => rand(256), 'blue' => rand(256)});
     $F->box(
-            {
-                'x'        => rand($XX),
-                  'y'        => rand($YY),
-                  'xx'       => rand($XX),
-                  'yy'       => rand($YY),
-                  'radius'   => rand(80) + 1,
-                  'filled'   => 1,
-                  'gradient' => {
-                      'start' => {
-                          'red'   => rand(256),
-                          'green' => rand(256),
-                          'blue'  => rand(256)
-                    },
-                      'end' => {
-                          'red'   => rand(256),
-                          'green' => rand(256),
-                          'blue'  => rand(256)
-                      }
-                  }
+        {
+            'x'        => rand($XX),
+            'y'        => rand($YY),
+            'xx'       => rand($XX),
+            'yy'       => rand($YY),
+            'radius'   => rand(80) + 1,
+            'filled'   => 1,
+            'gradient' => {
+                'start' => {
+                    'red'   => rand(256),
+                    'green' => rand(256),
+                    'blue'  => rand(256)
+                },
+                'end' => {
+                    'red'   => rand(256),
+                    'green' => rand(256),
+                    'blue'  => rand(256)
+                }
             }
-        );
-} ## end foreach my $p (1 .. (20 * $factor...))
+        }
+    );
+} ## end while (time < $s)
 
 print_it($F, 'Circle Test');
 $s = time + $factor;
@@ -165,44 +165,44 @@ while (time < $s) {
     $F->circle(
         {
             'x'        => rand($XX),
-              'y'        => rand($YY),
-              'radius'   => rand($center_y),
-              'filled'   => 1,
-              'gradient' => {
-                  'start' => {
-                      'red'   => rand(256),
-                      'green' => rand(256),
-                      'blue'  => rand(256)
-                  },
-                  'end' => {
-                      'red'   => rand(256),
-                      'green' => rand(256),
-                      'blue'  => rand(256)
-                  }
-              }
+            'y'        => rand($YY),
+            'radius'   => rand($center_y),
+            'filled'   => 1,
+            'gradient' => {
+                'start' => {
+                    'red'   => rand(256),
+                    'green' => rand(256),
+                    'blue'  => rand(256)
+                },
+                'end' => {
+                    'red'   => rand(256),
+                    'green' => rand(256),
+                    'blue'  => rand(256)
+                }
+            }
         }
     );
-}
+} ## end while (time < $s)
 
 print_it($F, 'Arc Test');
 $s = time + $factor;
 while (time < $s) {
     $F->set_color({'red' => rand(256), 'green' => rand(256), 'blue' => rand(256)});
-    $F->arc({'x' => rand($XX), 'y' => rand($YY), 'radius' => rand($center_y),'start_degrees' => rand(360),'end_degrees' => rand(360)});
+    $F->arc({'x' => rand($XX), 'y' => rand($YY), 'radius' => rand($center_y), 'start_degrees' => rand(360), 'end_degrees' => rand(360)});
 }
 
 print_it($F, 'Poly Arc Test');
 $s = time + $factor;
 while (time < $s) {
     $F->set_color({'red' => rand(256), 'green' => rand(256), 'blue' => rand(256)});
-    $F->poly_arc({'x' => rand($XX), 'y' => rand($YY), 'radius' => rand($center_y),'start_degrees' => rand(360),'end_degrees' => rand(360)});
+    $F->poly_arc({'x' => rand($XX), 'y' => rand($YY), 'radius' => rand($center_y), 'start_degrees' => rand(360), 'end_degrees' => rand(360)});
 }
 
 print_it($F, 'Filled Pie Test');
 $s = time + $factor;
 while (time < $s) {
     $F->set_color({'red' => rand(256), 'green' => rand(256), 'blue' => rand(256)});
-    $F->filled_pie({'x' => rand($XX), 'y' => rand($YY), 'radius' => rand($center_y),'start_degrees' => rand(360),'end_degrees' => rand(360)});
+    $F->filled_pie({'x' => rand($XX), 'y' => rand($YY), 'radius' => rand($center_y), 'start_degrees' => rand(360), 'end_degrees' => rand(360)});
 }
 
 print_it($F, 'Gradient Filled Pie Test');
@@ -211,26 +211,26 @@ while (time < $s) {
     $F->set_color({'red' => rand(256), 'green' => rand(256), 'blue' => rand(256)});
     $F->filled_pie(
         {
-            'x'        => rand($XX),
-              'y'        => rand($YY),
-              'radius'   => rand($center_y),
-              'start_degrees' => rand(360),
-              'end_degrees'   => rand(360),
-              'gradient' => {
-                  'start' => {
-                      'red'   => rand(256),
-                      'green' => rand(256),
-                      'blue'  => rand(256)
-                  },
-                  'end' => {
-                      'red'   => rand(256),
-                      'green' => rand(256),
-                      'blue'  => rand(256)
-                  }
-              }
+            'x'             => rand($XX),
+            'y'             => rand($YY),
+            'radius'        => rand($center_y),
+            'start_degrees' => rand(360),
+            'end_degrees'   => rand(360),
+            'gradient'      => {
+                'start' => {
+                    'red'   => rand(256),
+                    'green' => rand(256),
+                    'blue'  => rand(256)
+                },
+                'end' => {
+                    'red'   => rand(256),
+                    'green' => rand(256),
+                    'blue'  => rand(256)
+                }
+            }
         }
     );
-}
+} ## end while (time < $s)
 
 print_it($F, 'Ellipse Test');
 $s = time + $factor;
@@ -253,25 +253,25 @@ while (time < $s) {
     $F->ellipse(
         {
             'x'        => rand($XX),
-              'y'        => rand($YY),
-              'xradius'  => rand($center_x),
-              'yradius'  => rand($center_y),
-              'filled'   => 1,
-              'gradient' => {
-                  'start' => {
-                      'red'   => rand(256),
-                      'green' => rand(256),
-                      'blue'  => rand(256)
-                  },
-                  'end' => {
-                      'red'   => rand(256),
-                      'green' => rand(256),
-                      'blue'  => rand(256)
-                  }
-              }
+            'y'        => rand($YY),
+            'xradius'  => rand($center_x),
+            'yradius'  => rand($center_y),
+            'filled'   => 1,
+            'gradient' => {
+                'start' => {
+                    'red'   => rand(256),
+                    'green' => rand(256),
+                    'blue'  => rand(256)
+                },
+                'end' => {
+                    'red'   => rand(256),
+                    'green' => rand(256),
+                    'blue'  => rand(256)
+                }
+            }
         }
     );
-}
+} ## end while (time < $s)
 
 print_it($F, 'Polygon Test');
 $s = time + $factor;
@@ -294,22 +294,22 @@ while (time < $s) {
     $F->polygon(
         {
             'coordinates' => [rand($XX), rand($YY), rand($XX), rand($YY), rand($XX), rand($YY), rand($XX), rand($YY)],
-              'filled'      => 1,
-              'gradient'    => {
-                  'start' => {
-                      'red'   => rand(256),
-                      'green' => rand(256),
-                      'blue'  => rand(256)
-                  },
-                  'end' => {
-                      'red'   => rand(256),
-                      'green' => rand(256),
-                      'blue'  => rand(256)
-                  }
-              }
+            'filled'      => 1,
+            'gradient'    => {
+                'start' => {
+                    'red'   => rand(256),
+                    'green' => rand(256),
+                    'blue'  => rand(256)
+                },
+                'end' => {
+                    'red'   => rand(256),
+                    'green' => rand(256),
+                    'blue'  => rand(256)
+                }
+            }
         }
     );
-}
+} ## end while (time < $s)
 
 print_it($F, 'Testing Bezier Curves');
 
@@ -321,35 +321,35 @@ while (time < $s) {
         push(@coords, int(rand($XX)), int(rand($YY)));
     }
     $F->bezier({'coordinates' => \@coords, 'points' => 100});
-} ## end foreach my $z (1 .. (40 * $factor...))
+} ## end while (time < $s)
 
 {
     print_it($F, 'Testing TrueType Font Rendering (random height/width)');
 
     my $g = time + $factor;
-    while( time < $g) {
+    while (time < $g) {
         my $x  = int(rand(600 * $xm));
         my $y  = int(rand(900 * $ym));
-        my $h  = ($YY < 128) ? (6+rand(60)) : (8+int(rand(300 * $ym)));
+        my $h  = ($YY < 128) ? (6 + rand(60)) : (8 + int(rand(300 * $ym)));
         my $ws = ($XX < 256) ? rand(2) : rand(4);
-    
+
         my $b = $F->ttf_print(
             {
                 'x'            => $x,
-                  'y'            => $y,
-                  'height'       => $h,
-                  'wscale'       => $ws,
-                  'color'        => sprintf('%02x%02x%02x', int(rand(256)), int(rand(256)), int(rand(256))),
-                  'text'         => 'GFB',
-                  'bounding_box' => 1,
-                  'center'       => 3
+                'y'            => $y,
+                'height'       => $h,
+                'wscale'       => $ws,
+                'color'        => sprintf('%02x%02x%02x', int(rand(256)), int(rand(256)), int(rand(256))),
+                'text'         => 'GFB',
+                'bounding_box' => 1,
+                'center'       => 3
             }
         );
         if (defined($b)) {
             $b->{'x'} = rand($F->{'XX_CLIP'} - $b->{'pwidth'});
             $F->ttf_print($b);
         }
-    }
+    } ## end while (time < $g)
 }
 print_it($F, 'Testing flood fill');
 if ($XX > 255) {
@@ -359,18 +359,18 @@ if ($XX > 255) {
     $F->polygon({'coordinates' => [1270 * $xm, 570 * $ym, 970 * $xm, 170 * $ym, 600 * $xm, 500 * $ym]});
     $F->set_color({'red' => rand(256), 'green' => rand(256), 'blue' => rand(256)});
     $F->circle({'x' => 500 * $xm, 'y' => 320 * $ym, 'radius' => 100 * $xm});
-    
+
     $F->set_color({'red' => rand(256), 'green' => rand(256), 'blue' => rand(256)});
     $F->fill({'x' => 240 * $xm, 'y' => 200 * $ym});
-    
+
     $F->set_color({'red' => rand(256), 'green' => rand(256), 'blue' => rand(256)});
-    $F->fill({'x' => 960 *$xm, 'y' => 440 * $ym});
+    $F->fill({'x' => 960 * $xm, 'y' => 440 * $ym});
 } else {
     $F->set_color({'red' => rand(256), 'green' => rand(256), 'blue' => rand(256)});
-    $F->polygon({'coordinates' => [$center_x,3, 3,$YY - 3, $center_x,$center_y, $XX - 3,$YY - 4]});
+    $F->polygon({'coordinates' => [$center_x, 3, 3, $YY - 3, $center_x, $center_y, $XX - 3, $YY - 4]});
     $F->set_color({'red' => rand(256), 'green' => rand(256), 'blue' => rand(256)});
     $F->fill({'x' => 3, 'y' => 3});
-}
+} ## end else [ if ($XX > 255) ]
 
 print_it($F, 'Testing Color Replace (clipping on)');
 
@@ -389,15 +389,15 @@ while (time < $s) {
     $F->replace_color(
         {
             'old_red'   => $r,
-              'old_green' => $g,
-              'old_blue'  => $b,
-              'new_red'   => $R,
-              'new_green' => $G,
-              'new_blue'  => $B
+            'old_green' => $g,
+            'old_blue'  => $b,
+            'new_red'   => $R,
+            'new_green' => $G,
+            'new_blue'  => $B
         }
     );
     ($r, $g, $b) = ($R, $G, $B);
-}
+} ## end while (time < $s)
 
 print_it($F, 'Testing Color Replace (clipping off)');
 
@@ -416,15 +416,15 @@ while (time < $s) {
     $F->replace_color(
         {
             'old_red'   => $r,
-              'old_green' => $g,
-              'old_blue'  => $b,
-              'new_red'   => $R,
-              'new_green' => $G,
-              'new_blue'  => $B
+            'old_green' => $g,
+            'old_blue'  => $b,
+            'new_red'   => $R,
+            'new_green' => $G,
+            'new_blue'  => $B
         }
     );
     ($r, $g, $b) = ($R, $G, $B);
-}
+} ## end while (time < $s)
 
 print_it($F, 'Testing Image load (different sizes)');
 
@@ -440,7 +440,7 @@ while (time < $s) {
         }
     );
     $F->blit_write($image);
-}
+} ## end while (time < $s)
 my $image = $F->load_image(
     {
         'x'      => 0,
@@ -459,8 +459,8 @@ $image = $F->load_image(
     {
         'x'      => 0,
         'y'      => 0,
-        'width'  => min(640,$XX/2),
-        'height' => min(405,$YY/2),
+        'width'  => min(640, $XX / 2),
+        'height' => min(405, $YY / 2),
         'file'   => 'images/RWBY_Faces.png'
     }
 );
@@ -487,13 +487,13 @@ sub print_it {
 
         my $b = $fb->ttf_print(
             {
-                'x'            => 5  * $xm,
-                'y'            => max(9,20 * $ym),
-                'height'       => max(10,20 * $ym),
+                'x'            => 5 * $xm,
+                'y'            => max(9, 20 * $ym),
+                'height'       => max(10, 20 * $ym),
                 'color'        => '00FF00',
                 'text'         => $message,
                 'bounding_box' => 1,
-                'center'       => 0,
+                'center'       => $fb->{'CENTER_X'},
                 'antialias'    => 1
             }
         );
